@@ -258,14 +258,17 @@ class Application(VuetifyTemplate, HubListener):
         # Add a fitted_models dictionary that the helpers (or user) can access
         self.fitted_models = {}
 
-        # Add inverse colormaps to Glue global state. Also see ColormapRegistry in
+        # Add new and inverse colormaps to Glue global state. Also see ColormapRegistry in
         # https://github.com/glue-viz/glue/blob/main/glue/config.py
-        new_cms = (['Reversed: Gray', cm.gray_r],
+        new_cms = (['Rainbow', cm.rainbow],
+                   ['Seismic', cm.seismic],
+                   ['Reversed: Gray', cm.gray_r],
                    ['Reversed: Viridis', cm.viridis_r],
                    ['Reversed: Plasma', cm.plasma_r],
                    ['Reversed: Inferno', cm.inferno_r],
                    ['Reversed: Magma', cm.magma_r],
-                   ['Reversed: Hot', cm.hot_r])
+                   ['Reversed: Hot', cm.hot_r],
+                   ['Reversed: Rainbow', cm.rainbow_r])
         for cur_cm in new_cms:
             if cur_cm not in colormaps.members:
                 colormaps.add(*cur_cm)
@@ -524,15 +527,7 @@ class Application(VuetifyTemplate, HubListener):
                     parser = data_parser_registry.members.get(data_parser)
 
             if parser is not None:
-                # If the parser returns something other than known, assume it's
-                #  a message we want to make the user aware of.
-                msg = parser(self, file_obj, **kwargs)
-
-                if msg is not None:
-                    snackbar_message = SnackbarMessage(
-                        msg, color='error', sender=self)
-                    self.hub.broadcast(snackbar_message)
-                    return
+                parser(self, file_obj, **kwargs)
             else:
                 self._application_handler.load_data(file_obj)
 
@@ -1043,6 +1038,13 @@ class Application(VuetifyTemplate, HubListener):
             Removes all other currently plotted data and only shows the newly
             defined data set.
         """
+        if ('mosviz_row' in self.state.settings and
+            not (self.get_viewer("table-viewer").row_selection_in_progress) and
+            self.data_collection[data_label].meta['mosviz_row'] !=
+                self.state.settings['mosviz_row']):
+            raise NotImplementedError("Intra-row plotting not supported. "
+                                      "Please use the table viewer to change rows")
+
         viewer_item = self._get_viewer_item(viewer_reference)
         if viewer_item is None:
             raise ValueError(f"Could not identify viewer with reference {viewer_reference}")
@@ -1161,10 +1163,10 @@ class Application(VuetifyTemplate, HubListener):
         from jdaviz.configs.specviz2d.plugins import SpectralExtraction
         from jdaviz.configs.cubeviz.plugins.viewers import CubevizProfileView, CubevizImageView
         from jdaviz.configs.mosviz.plugins.viewers import (
-            MosvizProfileView, MosvizTableViewer, MosvizProfile2DView
+            MosvizTableViewer, MosvizProfile2DView
         )
 
-        spectral_viewers = (SpecvizProfileView, CubevizProfileView, MosvizProfileView)
+        spectral_viewers = (SpecvizProfileView, CubevizProfileView)
         table_viewers = (MosvizTableViewer, )
         image_viewers = (MosvizProfile2DView, CubevizImageView, SpectralExtraction)
         flux_viewers = (CubevizImageView, )
@@ -1646,6 +1648,17 @@ class Application(VuetifyTemplate, HubListener):
             msg.cls, data=msg.data, show=False)
         viewer.figure_widget.layout.height = '100%'
 
+        links_control_plugin = self._jdaviz_helper.plugins.get('Links Control', None)
+        if links_control_plugin is not None:
+            viewer.state.linked_by_wcs = links_control_plugin.link_type.selected == 'WCS'
+        elif len(self._viewer_store):
+            # The plugin would only not exist for instances of Imviz where the user has
+            # intentionally removed the Links Control plugin, but in that case we will
+            # adopt "linked_by_wcs" from the first (assuming all are the same)
+            # NOTE: deleting the default viewer is forbidden both by API and UI, but if
+            # for some reason that was the case here, linked_by_wcs will default to False
+            viewer.state.linked_by_wcs = list(self._viewer_store.values())[0].state.linked_by_wcs
+
         if msg.x_attr is not None:
             x = msg.data.id[msg.x_attr]
             viewer.state.x_att = x
