@@ -211,3 +211,6 @@ def test_cube_fitting_backend(unc):
     assert np.allclose(fitted_model[2].stddev.value, 0.1, atol=TOL)
 
     assert np.allclose(fitted_model[3].amplitude.value, 4.0, atol=TOL)
+
+    # Check that the fitted spectrum is masked correctly:
+    assert np.all(fitted_spectrum.mask == mask)
