@@ -107,3 +107,7 @@ def test_user_api(cubeviz_helper, spectrum1d_cube):
     # try eq on both text and value
     assert po.image_colormap == 'gray'
     assert po.image_colormap == 'Gray'
+
+    # toggle contour (which has a spinner implemented)
+    po.contour_visible = True
+    assert po._obj.contour_spinner is False
