@@ -7,6 +7,7 @@ from astropy.io import fits
 from astropy.nddata import NDData
 from astropy.wcs import WCS
 from glue.core.data import Component, Data
+from gwcs.wcs import WCS as GWCS
 
 from jdaviz.core.registries import data_parser_registry
 from jdaviz.core.events import SnackbarMessage
@@ -124,6 +125,14 @@ def _parse_image(app, file_obj, data_label, ext=None):
     data_iter = get_image_data_iterator(app, file_obj, data_label, ext=ext)
 
     for data, data_label in data_iter:
+        if isinstance(data.coords, GWCS) and (data.coords.bounding_box is not None):
+            # keep a copy of the original bounding box so we can detect
+            # when extrapolating beyond, but then remove the bounding box
+            # so that image layers are not cropped.
+            # NOTE: if extending this beyond GWCS, the mouseover logic
+            # for outside_*_bounding_box should also be updated.
+            data.coords._orig_bounding_box = data.coords.bounding_box
+            data.coords.bounding_box = None
         data_label = app.return_data_label(data_label, alt_name="image_data")
         app.add_data(data, data_label)
 
