@@ -1,13 +1,14 @@
 import warnings
 
 from astropy import units as u
+from astropy.utils.decorators import deprecated
 from specutils import SpectralRegion, Spectrum1D
 
 from jdaviz.core.helpers import ConfigHelper
 from jdaviz.core.events import RedshiftMessage
 from jdaviz.configs.default.plugins.line_lists.line_list_mixin import LineListMixin
 
-__all__ = ['Specviz', 'SpecViz']
+__all__ = ['Specviz']
 
 
 def _apply_redshift_to_spectra(spectra, redshift):
@@ -39,27 +40,32 @@ class Specviz(ConfigHelper, LineListMixin):
                                handler=self._redshift_listener)
 
     def load_spectrum(self, data, data_label=None, format=None, show_in_viewer=True,
-                      spectrum_viewer_reference_name=None):
-
-        # If viewer reference name is not specified and
-        # the default viewer is available, use default
-        if spectrum_viewer_reference_name is None:
-            if (self._default_spectrum_viewer_reference_name in
-                    self.app.get_viewer_reference_names()):
-                spectrum_viewer_reference_name = self._default_spectrum_viewer_reference_name
-
-            # If viewer reference name is not specified and default is unavailable,
-            # use first spectrum viewer without loaded data:
-            else:
-                spectrum_viewer_reference_name = self.app._get_first_viewer_reference_name(
-                    require_spectrum_viewer=True, require_no_selected_data=True
-                )
+                      concat_by_file=False):
+        """
+        Loads a data file or `~specutils.Spectrum1D` object into Specviz.
 
+        Parameters
+        ----------
+        data : str, `~specutils.Spectrum1D`, or `~specutils.SpectrumList`
+            Spectrum1D, SpectrumList, or path to compatible data file.
+        data_label : str
+            The Glue data label found in the ``DataCollection``.
+        format : str
+            Loader format specification used to indicate data format in
+            `~specutils.Spectrum1D.read` io method.
+        show_in_viewer : bool
+            Show data in viewer(s).
+        concat_by_file : bool
+            If True and there is more than one available extension, concatenate
+            the extensions within each spectrum file passed to the parser and
+            add a concatenated spectrum to the data collection.
+        """
         super().load_data(data,
                           parser_reference='specviz-spectrum1d-parser',
                           data_label=data_label,
                           format=format,
-                          show_in_viewer=show_in_viewer)
+                          show_in_viewer=show_in_viewer,
+                          concat_by_file=concat_by_file)
 
     def get_spectra(self, data_label=None, apply_slider_redshift="Warn"):
         """Returns the current data loaded into the main viewer
@@ -235,8 +241,7 @@ class Specviz(ConfigHelper, LineListMixin):
         ).figure.axes[axis].tick_format = fmt
 
 
-# TODO: Officially deprecate this with coordination with JDAT notebooks team.
-# For backward compatibility only.
+@deprecated('3.2', alternative='Specviz')
 class SpecViz(Specviz):
     """This class is pending deprecation. Please use `Specviz` instead."""
     pass
